@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.25 2005/01/05 04:15:20 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.27 2005/02/02 14:33:38 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -58,32 +58,32 @@ static void myexit(int code);
 static RETSIGTYPE exit_handler(int sig);
 static RETSIGTYPE reap_handler(int sig);
 static RETSIGTYPE failover_handler(int sig);
+static RETSIGTYPE health_check_timer_handler(int sig);
 
 static void usage(void);
 static void stop_me(void);
+static void switch_me(void);
 
-/* set unix domain socket path */
-struct sockaddr_un un_addr;
+static struct sockaddr_un un_addr;		/* unix domain socket path */
 
-/* child pid table */
-pid_t *pids;
+static pid_t *pids;	/* child pid table */
 
-int unix_fd;
-int inet_fd;
+static int unix_fd;	/* unix domain socket fd */
+static int inet_fd;	/* inet domain socket fd */
 
-int exiting = 0;
-int switching = 0;
+static int exiting = 0;		/* non 0 if I'm exiting */
+static int switching = 0;		/* non 0 if I'm fail overing or degenerating */
+static int degenerated = 0;	/* set non 0 if already degerated */
 
-int not_detach = 0;
-int debug = 0;
+static int not_detach = 0;		/* non 0 if non detach option (-n) is given */
+int debug = 0;	/* non 0 if debug option is given (-d) */
 
-pid_t mypid;
+static pid_t mypid;	/* pgpool parent process id */
 
 long int weight_master;	/* normalized weight of master (0-RAND_MAX range) */
 
-static int stop_sig = SIGTERM;
-
-static int degenerated = 0;	/* set non 0 if already degerated */
+static int stop_sig = SIGTERM;	/* stopping signal default value */
+static int switch_over_sig = SIGUSR1;	/* switch over signal default value */
 
 /*
 * pgpool main program
@@ -97,11 +97,15 @@ int main(int argc, char **argv)
 
 	snprintf(conf_file, sizeof(conf_file), "%s/%s", DEFAULT_CONFIGDIR, POOL_CONF_FILE_NAME);
 
-	while ((opt = getopt(argc, argv, "f:hm:nd")) != -1)
+	while ((opt = getopt(argc, argv, "df:hm:ns:")) != -1)
 	{
 		switch (opt)
 		{
-			case 'f':
+			case 'd':	/* debug option */
+				debug = 1;
+				break;
+
+			case 'f':	/* specify configuration file */
 				if (!optarg)
 				{
 					usage();
@@ -109,11 +113,13 @@ int main(int argc, char **argv)
 				}
 				strncpy(conf_file, optarg, sizeof(conf_file));
 				break;
+
 			case 'h':
 				usage();
 				exit(0);
 				break;
-			case 'm':
+
+			case 'm':	/* stop mode */
 				if (!optarg)
 				{
 					usage();
@@ -132,12 +138,27 @@ int main(int argc, char **argv)
 				}
 				break;
 				
-			case 'n':
+			case 'n':	/* no detaching control ttys */
 				not_detach = 1;
 				break;
-			case 'd':
-				debug = 1;
+
+			case 's':	/* switch over request */
+				if (!optarg)
+				{
+					usage();
+					exit(1);
+				}
+				if (*optarg == 'm' || !strcmp("master", optarg))
+					switch_over_sig = SIGUSR1;		/* stopping master */
+				else if (*optarg == 's' || !strcmp("secondary", optarg))
+					switch_over_sig = SIGUSR2;		/* stopping secondary */
+				else
+				{
+					usage();
+					exit(1);
+				}
 				break;
+
 			default:
 				usage();
 				exit(1);
@@ -160,10 +181,18 @@ int main(int argc, char **argv)
 						   (pool_config.weight_master + pool_config.weight_secondary));
 	pool_debug("weight: %ld", weight_master);
 
-	if (optind == (argc - 1) && !strcmp(argv[optind], "stop"))
+	if (optind == (argc - 1))
 	{
-		stop_me();
-		exit(0);
+		if (!strcmp(argv[optind], "stop"))
+		{
+			stop_me();
+			exit(0);
+		}
+		else if (!strcmp(argv[optind], "switch"))
+		{
+			switch_me();
+			exit(0);
+		}
 	}
 	else if (optind == argc)
 	{
@@ -235,28 +264,55 @@ int main(int argc, char **argv)
 	pool_signal(SIGUSR1, failover_handler);
 	pool_signal(SIGUSR2, failover_handler);
 
+	/*
+	 * This is the main loop
+	 */
 	for (;;)
 	{
-#ifdef HEALTH_CHECK
-		int sts;
-
-		sleep(5);
-
-		if (!degenerated)
+		/* do we need health checking for PostgreSQL? */
+		if (!degenerated && pool_config.health_check_period > 0)
 		{
+			int sts;
+
+			pool_log("starting health checking");
+
+			if (pool_config.health_check_timeout > 0)
+			{
+				/*
+				 * set health checker timeout. we want to detect
+				 * commnuication path failure much earlier before
+				 * TCP/IP statck detects it.
+				 */
+				pool_signal(SIGALRM, health_check_timer_handler);
+				alarm(pool_config.health_check_timeout);
+			}
+
+			/*
+			 * do actual health check. trying to connect to the backend
+			 */
 			sts = health_check();
 			if (sts == -1)
 			{
-				failover_handler(SIGUSR1);
+				failover_handler(SIGUSR1);		/* master down */
+
 			}
 			else if (sts == -2)
 			{
-				failover_handler(SIGUSR2);
+				failover_handler(SIGUSR2);		/* secondary down */
 			}
+
+			if (pool_config.health_check_timeout > 0)
+			{
+				/* seems ok. cancel health check timer */
+				pool_signal(SIGALRM, SIG_IGN);
+			}
+
+			sleep(pool_config.health_check_period);
+		}
+		else
+		{
+			pause();
 		}
-#else
-		pause();
-#endif
 	}
 	return 0;
 }
@@ -265,11 +321,15 @@ static void usage(void)
 {
 	fprintf(stderr, "pgpool version %s(%s),\n",	VERSION, PGPOOLVERSION);
 	fprintf(stderr, "  a generic connection pool/replication/load balance server for PostgreSQL\n\n");
-	fprintf(stderr, "usage: pgpool [-f config_file][-n][-d][-h][[-m {s[mart]|f[ast]|i[mmediate]}] stop]\n");
+	fprintf(stderr, "usage: pgpool [-f config_file][-n][-d]\n");
+	fprintf(stderr, "usage: pgpool [-f config_file] [-m {s[mart]|f[ast]|i[mmediate]}] stop\n");
+	fprintf(stderr, "usage: pgpool [-f config_file] [-s {m[aster]|s[econdary]] switch\n");
+	fprintf(stderr, "usage: pgpool -h\n");
 	fprintf(stderr, "  config_file default path: %s/%s\n",DEFAULT_CONFIGDIR, POOL_CONF_FILE_NAME);
 	fprintf(stderr, "  -n: don't run in daemon mode. does not detatch control tty\n");
 	fprintf(stderr, "  -d: debug mode. lots of debug information will be printed\n");
 	fprintf(stderr, "  stop: stop pgpool\n");
+	fprintf(stderr, "  switch: send switch over request to pgpool\n");
 	fprintf(stderr, "  -h: print this help\n");
 }
 
@@ -310,30 +370,21 @@ static void daemonize(void)
 	write_pid_file();
 }
 
+
 /*
 * stop myself
 */
 static void stop_me(void)
 {
-	FILE *fd;
-	char path[POOLMAXPATHLEN];
-	char pidbuf[128];
 	pid_t pid;
 
-	snprintf(path, sizeof(path), "%s/%s", pool_config.logdir, PID_FILE_NAME);
-	fd = fopen(path, "r");
-	if (!fd)
+	pid = read_pid_file();
+	if (pid < 0)
 	{
-		pool_error("could not open pid file as %s. reason: %s",
-				   path, strerror(errno));
+		pool_error("could read pid file");
 		exit(1);
 	}
 
-	memset(pidbuf, 0, sizeof(pidbuf));
-	fread(pidbuf, sizeof(pidbuf), 1, fd);
-	pid = atoi(pidbuf);
-	fclose(fd);
-
 	if (kill(pid, stop_sig) == -1)
 	{
 		pool_error("could not stop pid: %d. reason: %s", pid, strerror(errno));
@@ -350,6 +401,30 @@ static void stop_me(void)
 	fprintf(stderr, "done.\n");
 }
 
+/*
+* switch over request
+*/
+static void switch_me(void)
+{
+	pid_t pid;
+
+	pid = read_pid_file();
+
+	if (pid < 0)
+	{
+		pool_error("could read pid file");
+		exit(1);
+	}
+
+	if (kill(pid, switch_over_sig) == -1)
+	{
+		pool_error("could not send switch over request to pid: %d. reason: %s", pid, strerror(errno));
+		exit(1);
+	}
+
+	pool_log("switch over request sent");
+}
+
 /*
 * read the pid file
 */
@@ -629,12 +704,18 @@ static RETSIGTYPE failover_handler(int sig)
 		return;
 	}
 
+	/*
+	 * processing SIGTERM, SIGINT or SIGQUIT
+	 */
 	if (exiting)
 	{
 		POOL_SETMASK(&UnBlockSig);
 		return;
 	}
 
+	/*
+	 * processing fail over or switch over
+	 */
 	if (switching)
 	{
 		POOL_SETMASK(&UnBlockSig);
@@ -648,10 +729,10 @@ static RETSIGTYPE failover_handler(int sig)
 #endif
 
 	/* 
-	 * if not in replication mode, we treat this a restart request.
+	 * if not in replication mode/master slave mode, we treat this a restart request.
 	 * otherwise we need to check if we have already failovered.
 	 */
-	if (!pool_config.replication_enabled ||
+	if (!pool_config.replication_enabled || !pool_config.master_slave_enabled ||
 		strcmp(pool_config.current_backend_host_name, pool_config.secondary_backend_host_name) ||
 		pool_config.current_backend_port != pool_config.secondary_backend_port)
 	{
@@ -767,6 +848,16 @@ static RETSIGTYPE failover_handler(int sig)
 	POOL_SETMASK(&UnBlockSig);
 }
 
+/*
+ * health check timer handler
+ */
+static RETSIGTYPE health_check_timer_handler(int sig)
+{
+	POOL_SETMASK(&BlockSig);
+
+	POOL_SETMASK(&UnBlockSig);
+}
+
 /*
  * handle SIGCHLD
  */
