@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.29 2005/01/05 13:27:20 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.31 2005/02/02 14:33:38 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -136,10 +136,18 @@ typedef struct {
 											 */
 	char **reset_query_list;		/* comma separated list of quries to be issued at the end of session */
 
+	int print_timestamp;		/* if non 0 print time stamp to each log line */
+	int master_slave_mode;		/* if non 0, operate in master/slave mode */
+	int connection_cache;		/* if non 0, cache connection pool */
+	int health_check_timeout;	/* health check timeout */
+	int health_check_period;	/* health check period */
+	char *health_check_user;		/* PostgreSQL user name for health check */
+
 	/* followings do not exist in the configuration file */
     char *current_backend_host_name;	/* current backend host name */
     int	current_backend_port;	/* current backend port # */
 	int replication_enabled;		/* replication mode enabled */
+	int master_slave_enabled;		/* master/slave mode enabled */
 	int num_reset_queries;		/* number of queries in reset_query_list */
 } POOL_CONFIG;
 
@@ -215,6 +223,8 @@ typedef struct {
 #define MASTER_CONNECTION(p) ((p)->slots[0])
 #define SECONDARY_CONNECTION(p) ((p)->slots[1])
 #define REPLICATION (pool_config.replication_enabled)
+#define MASTER_SLAVE (pool_config.master_slave_enabled)
+#define DUAL_MODE (REPLICATION || MASTER_SLAVE)
 #define MASTER(p) MASTER_CONNECTION(p)->con
 #define SECONDARY(p) SECONDARY_CONNECTION(p)->con
 #define MAJOR(p) MASTER_CONNECTION(p)->sp->major
