@@ -1,11 +1,11 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_auth.c,v 1.14 2004/08/13 11:47:51 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_auth.c,v 1.18 2005/01/30 13:04:06 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003, 2004	Tatsuo Ishii
+ * Copyright (c) 2003-2005	Tatsuo Ishii
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -109,7 +109,7 @@ int pool_do_auth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 		return -1;
 	}
 
-	if (REPLICATION)
+	if (DUAL_MODE)
 	{
 		status = pool_read(SECONDARY(cp), &pid1, sizeof(pid1));
 
@@ -148,7 +148,7 @@ int pool_do_auth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 
 		pid = do_clear_text_password(MASTER(cp), frontend, 0, protoMajor);
 
-		if (pid >= 0 && REPLICATION)
+		if (pid >= 0 && DUAL_MODE)
 		{
 			pid = do_clear_text_password(SECONDARY(cp), frontend, 0, protoMajor);
 		}
@@ -161,7 +161,7 @@ int pool_do_auth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 
 		pid = do_crypt(MASTER(cp), frontend, 0, protoMajor);
 
-		if (pid >= 0 && REPLICATION)
+		if (pid >= 0 && DUAL_MODE)
 		{
 			pid = do_crypt(SECONDARY(cp), frontend, 0, protoMajor);
 		}
@@ -174,7 +174,7 @@ int pool_do_auth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 
 		pid = do_md5(MASTER(cp), frontend, 0, protoMajor);
 
-		if (pid >= 0 && REPLICATION)
+		if (pid >= 0 && DUAL_MODE)
 		{
 			pid = do_md5(SECONDARY(cp), frontend, 0, protoMajor);
 		}
@@ -253,7 +253,7 @@ int pool_do_auth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 	pool_read(MASTER(cp), &key, sizeof(key));
 	MASTER_CONNECTION(cp)->key = key;
 
-	if (REPLICATION)
+	if (DUAL_MODE)
 	{
 		pool_read(SECONDARY(cp), &pid1, sizeof(pid1));
 		SECONDARY_CONNECTION(cp)->pid = pid;
@@ -697,6 +697,8 @@ static int do_md5(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int reaut
 			pool_error("do_md5: failed to read salt");
 			return -1;
 		}
+		pool_debug("master: %d salt: %hhx%hhx%hhx%hhx", !backend->issecondary_backend,
+				   salt[0], salt[1], salt[2], salt[3]);
 	}
 	else
 	{
@@ -856,7 +858,9 @@ int pool_read_message_length(POOL_CONNECTION_POOL *cp)
 	}
 	length = ntohl(length);
 
-	if (REPLICATION)
+	pool_debug("read_message_length: lenghth: %d", length);
+
+	if (DUAL_MODE)
 	{
 		status = pool_read(SECONDARY(cp), &length1, sizeof(length1));
 		if (status < 0)
@@ -895,7 +899,7 @@ signed char pool_read_kind(POOL_CONNECTION_POOL *cp)
 		return -1;
 	}
 
-	if (REPLICATION)
+	if (DUAL_MODE)
 	{
 		status = pool_read(SECONDARY(cp), &kind1, sizeof(kind1));
 		if (status < 0)
