@@ -1,11 +1,11 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_connection_pool.c,v 1.27 2004/12/14 05:09:29 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_connection_pool.c,v 1.29 2005/01/30 13:04:06 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003, 2004	Tatsuo Ishii
+ * Copyright (c) 2003-2005	Tatsuo Ishii
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -109,7 +109,7 @@ void pool_discard_cp(char *user, char *database, int protoMajor)
 	pool_free_startup_packet(MASTER_CONNECTION(p)->sp);
 	pool_close(MASTER_CONNECTION(p)->con);
 
-	if (pool_config.replication_enabled)
+	if (DUAL_MODE)
 	{
 		/* do not free memory! we did not allocate them */
 		pool_close(SECONDARY_CONNECTION(p)->con);
@@ -175,7 +175,7 @@ POOL_CONNECTION_POOL *pool_create_cp(void)
 	pool_free_startup_packet(MASTER_CONNECTION(p)->sp);
 	pool_close(MASTER_CONNECTION(p)->con);
 
-	if (pool_config.replication_enabled)
+	if (DUAL_MODE)
 	{
 		/* do not free memory! we did not allocate them */
 		pool_close(SECONDARY_CONNECTION(p)->con);
@@ -260,7 +260,7 @@ RETSIGTYPE pool_backend_timer_handler(int sig)
 				pool_free_startup_packet(MASTER_CONNECTION(p)->sp);
 				pool_close(MASTER_CONNECTION(p)->con);
 
-				if (pool_config.replication_enabled)
+				if (DUAL_MODE)
 				{
 					/* do not free memory! we did not allocate them */
 					pool_close(SECONDARY_CONNECTION(p)->con);
@@ -430,7 +430,7 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 	p->num = 1;	/* number of slots */
 
 	/* create secondary connection */
-	if (pool_config.replication_enabled)
+	if (DUAL_MODE)
 	{
 		SECONDARY_CONNECTION(p) = malloc(sizeof(POOL_CONNECTION_POOL_SLOT));
 		if (SECONDARY_CONNECTION(p) == NULL)
